#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_IFLOOR_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_IFLOOR_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/ifloor.hpp>

#endif
